/*-----------------------------------------------------------------
  All code is provided for EDUCATIONAL purposes ONLY. There is no
  warranty and no support.

  Copyright (c) Jack Botner and licensed under the MIT license; see
  http://opensource.org/licenses/mit-license.php

  space heater controller by Jack Botner

  main.h
-----------------------------------------------------------------*/
#ifndef _MAIN_H_
#define _MAIN_H_

#include "common.h"

#define INIT_TIMER1			( 65536 - 31250 )    // set the timer counts
#define INIT_TIMER0			( 256 - 125 )

#define MAX_CHECKS       	4		    // number of tests before a switch is debounced

// The following number, in 10ths degrees C, should be an even number, because
// it is divided by 2 then added to set temperature to become Tos and subtracted
// from set temperature to become Thyst.
#define TEMP_HYSTERESIS_TENTHS    16		// hysteresis, tenths degrees C

// Event flag bits
#define EVENT_ANALYZE_STATE		 1
#define EVENT_UPDATE_TOS_THYST 2
#define EVENT_UPDATE_EEPROM		 3
#define EVENT_BUTTON_PRESSED	 4
#define EVENT_ENCODER_UP		   5
#define EVENT_ENCODER_DOWN		 6

#define DIAG_LED_PORT     PORTB
#define DIAG_LED_PIN          2

// Debounced switches bits
#define ENC_SWITCH_A			0
#define ENC_SWITCH_B			1
#define ENC_SWITCH_PB			2

// Rotary encoder port defines
#define ENCODER_PORT			PINA
#define ENCODER_B				  PINA1
#define ENCODER_A				  PINA0
#define ENCODER_PB				PINA2

// Relay port defines
#define RELAY_PORT_OUT		PORTA
#define RELAY_PORT_IN			PINA
#define RELAY_PIN				  PORTA3

// DS1775 OS port defines
#define OS_PORT_IN		    PINA
#define OS_PIN            PORTA7

// EEPROM stuff
typedef struct _MY_EEPROM_DATA
{
	int16_t	  iSetTempC;			// last set temperature (10ths degrees C)
	uint8_t	  ucSystemOn;		    // on/off switch
}
MY_EEPROM_DATA;

// Functions

#endif  //_MAIN_H_
